.field {
    .search-filter & {
        margin-bottom: 2rem;
    }

    label {
        display: inline-block;
        margin-bottom: 0.5rem;
    }

    &.select-field,
    &.text-field {
        label {
            width: 100%;
        }
    }
}
