#bandi-search {
    .search-results {
        .bando-result {
            margin: 3rem 0;

            .bandoTitle {
                display: flex;
                padding-left: 0;
                margin-bottom: 1rem;

                span.bandoStateClass {
                    font-size: 13px;
                }

                a {
                    align-self: center;
                    font-size: 21.6px;
                    text-decoration: underline;
                }
            }

            .bandoDates {
                margin-top: 1rem;

                p {
                    margin: 0;
                }
            }
            .separator {
                margin: 0 5px;
            }
        }
    }
}
