.field.checkbox-field {
    .checkbox-option {
        label {
            display: inline-flex;
            align-items: flex-start;
            font-weight: normal;
            input {
                margin-right: 10px;
                margin-top: 0.4em;
            }
        }
    }

    fieldset {
        legend {
            border-bottom: 0;
            margin-bottom: 1rem;
            font-weight: bold;
            color: inherit;
            font-size: inherit;
        }
    }
}
