#bandi-search {
    .search-filter {
        @media (min-width: 1200px) {
            padding-right: 10rem;
        }

        @media (max-width: 991px) {
            margin-bottom: 3rem;

            .collapse-btn[aria-expanded='true'] {
                margin-bottom: 3rem;
            }
        }

        > h2 {
            margin-top: 0;
            margin-bottom: 3rem;
        }

        .reset-filters {
            margin-top: 3rem;
        }
    }
}
