body#visual-portal-wrapper {
  &.pat-plone {
    #edit-bar {
      #edit-zone {
        .contenttype-bando:after {
          content: '';
          background-image: url('/++plone++rer.bandi.images/bando_icon.svg');
          background-position: center;
          background-repeat: no-repeat;
          background-size: 1em;
        }
      }
    }
  }
}

.visualClear {
  clear: both;
}

.rer-contextual-portlets-right {
  width: 17em;
  margin-left: 1em;
  float: right;
}

body.portaltype-bando {
  #content {
    .rer-contextual-text,
    .rer-contextual-portlets {
      a {
        background: none;
        padding: 1px 0 1px 1px;
        text-decoration: underline;
      }

      .bandoInfos {
        padding: 0;
      }
    }
  }
}

.rer-contextual-description {
  margin-bottom: 10px;
}

.contextualbody .navTreeItem li {
  list-style-type: none;
}

.rer-contextual-portlets ul {
  margin: 0.5em 0 0 0.5em;
}

.contextualbody {
  .navTreeItem {
    &,
    dd.portletItem & {
      a {
        display: inline;
      }
    }
  }
}

.tableRight {
  width: 100%;
}

.bandiColumnRight {
  width: 40%;
  float: right;
  margin-left: 1em;

  @media (max-width: 768px) {
    width: auto;
    float: none;
    margin: 1rem 0 3rem;
  }
}

/*** etichette bandi ***/

.bandoInfos,
.bandoTitle {
  .bandoStateClass {
    background-position: 5px 0;
    background-repeat: no-repeat;
    display: block;
    float: left;
    font-size: 13px;
    font-weight: normal;
    margin-right: 1em;
    padding-top: 5px;
    text-transform: uppercase;
    width: 57px;
    min-width: 57px;
    line-height: 3rem;
    text-align: center;
  }

  table & {
    .bandoStateClass {
      width: auto;
      text-align: center;
    }
  }
}

a.bandoTitle {
  border-bottom: 1px solid #cccccc;
  text-decoration: none;
}

a.bandoTitleLink {
  border-bottom: 1px solid;
}

.bandoStateClass {
  .bandoInfos & {
    margin-top: 4px;
  }

  .bandoTitle & {
    font-size: 13px;
    margin-bottom: 0;
    margin-top: 7px;
    text-align: center;

    .searchResults & {
      margin-top: 3px;
    }
  }
}

h3.bandoTitle {
  margin-top: 0;
  padding: 0 0 0 70px;
}

h2.bandoTitle,
.bandoInfos {
  padding: 15px 0;
}

.tileContent {
  .bandoInfos {
    padding-left: 75px;
  }
}

.bandoTitle,
.bandoInfos {
  position: relative;

  .tileContent & {
    .bandoStateClass {
      position: absolute;
      top: 3rem;
      left: 0;
    }
  }

  .searchResults & {
    .bandoStateClass {
      float: left;
    }
  }

  .state-open,
  .state-inProgress,
  .state-closed {
    // float: none;
    padding: 15px 0 5px;
    // color: #666;
    // font-weight: 600;
    // border-top: 5px solid;
  }

  .state-open {
    background-image: url(++plone++rer.bandi.images/bando_open.png);
    // color: #255a01;
    color: #1c2024;
  }

  .state-inProgress {
    background-image: url(++plone++rer.bandi.images/bando_inprogress.png);
    // color: #9c6f02;
    color: #1c2024;
  }

  .state-closed {
    background-image: url(++plone++rer.bandi.images/bando_closed.png);
    color: #1c2024;
    // color: #700;
  }
}

.bandi-collection {
  .bando-item {
    position: relative;

    h2.bandoTitle {
      font-size: 120%;
      font-weight: normal;
      margin: 2em 0 0;
      display: inline-flex;

      a {
        border: 0;
        margin-left: 70px;

        span {
          border-bottom: 1px solid;
        }
      }

      .bandoStateClass {
        position: absolute;
        top: 15px;
        left: 0;
      }
    }
  }
}

#bandi-search {
  .bando-result {
    .bandoTitle {
      display: inline-flex;

      a {
        display: inline-block;
        margin-left: 70px;
      }

      .bandoStateClass {
        position: absolute;
        top: 10px;
        left: 0;
        margin: 0;
      }
    }
  }
}

.bandoDetail {
  clear: both;
}

.bandoDetail,
.searchResults .bandoDetail {
  margin: 0 0 0 70px;
  clear: none;
}

.bandoItem {
  border-bottom: 1px dashed #ccc;
  padding: 0.5em 0 0.7em;
  margin: 0.5em 0;
}

.labelTB {
  font-weight: bold;
}

.bandoDates {
  display: flex;
  flex-wrap: wrap;

  .colspacer {
    padding: 0 10px;
  }
}

p.bandoType {
  color: #666;
  font-size: 0.9em;
  font-style: italic;
  margin: 0;
}

.siteSelection {
  margin-left: 2em;
  margin-top: 1em;
}

.collectionTile.no-description {
  .bandoDescription {
    display: none;
  }
}

.solr-search-actions {
  > p {
    margin-top: 15px;
    margin-bottom: 0;
  }
}

.solr-search-actions,
.solr-search-results {
  a {
    border-bottom: 1px solid;
  }
}

.bandi-collection {
  .tile-wrapper {
    padding: 20px 0;
    position: relative;
  }

  .showMore {
    position: absolute;
    top: 20px;
    right: 0;
    padding: 10px 0;
  }

  .showMore a {
    border-bottom: 1px solid;
  }

  ul.tileContent {
    padding-left: 0;
  }
}
